@@ -5,6 +5,7 @@ import functools
 import sys
 
 from ssort._bindings import get_bindings
+from ssort._builtins import CLASS_BUILTINS
 
 
 class Scope(enum.Enum):
@@ -113,7 +114,7 @@ def _get_requirements_for_class_def(node):
     for base in node.bases:
         yield from get_requirements(base)
 
-    scope = set()
+    scope = set(CLASS_BUILTINS)
 
     for statement in node.body:
         for stmt_dep in get_requirements(statement):
@@ -706,6 +707,7 @@ def _get_requirements_for_attribute(node):
         # the following expression can appear in assignment context
         Attribute(expr value, identifier attr, expr_context ctx)
     """
+    assert isinstance(node.ctx, (ast.Load, ast.Del))
     yield from get_requirements(node.value)
 
 
@@ -716,6 +718,7 @@ def _get_requirements_for_subscript(node):
 
         Subscript(expr value, expr slice, expr_context ctx)
     """
+    assert isinstance(node.ctx, (ast.Load, ast.Del))
     yield from get_requirements(node.value)
     yield from get_requirements(node.slice)
 
@@ -727,7 +730,7 @@ def _get_requirements_for_starred(node):
 
         Starred(expr value, expr_context ctx)
     """
-    assert isinstance(node.ctx, ast.Load)
+    assert isinstance(node.ctx, (ast.Load, ast.Del))
     yield from get_requirements(node.value)
 
 
@@ -739,6 +742,7 @@ def _get_requirements_for_name(node):
 
         Name(identifier id, expr_context ctx)
     """
+    assert isinstance(node.ctx, (ast.Load, ast.Del))
     yield Requirement(
         name=node.id, lineno=node.lineno, col_offset=node.col_offset
     )
@@ -752,7 +756,7 @@ def _get_requirements_for_list(node):
 
         List(expr* elts, expr_context ctx)
     """
-    assert isinstance(node.ctx, ast.Load)
+    assert isinstance(node.ctx, (ast.Load, ast.Del))
     for element in node.elts:
         yield from get_requirements(element)
 
@@ -765,7 +769,7 @@ def _get_requirements_for_tuple(node):
         Tuple(expr* elts, expr_context ctx)
 
     """
-    assert isinstance(node.ctx, ast.Load)
+    assert isinstance(node.ctx, (ast.Load, ast.Del))
     for element in node.elts:
         yield from get_requirements(element)
 
